'use strict';

var tokens = require('../../design-tokens/vendor/tokens.cjs');
var convertValue = require('../../utils/convert-value.cjs');

const pxTextSizes = {
  textSans: {
    xxsmall: convertValue.pxStringToNumber(tokens.typography.textSans.xxSmall.fontSize),
    xsmall: convertValue.pxStringToNumber(tokens.typography.textSans.xSmall.fontSize),
    small: convertValue.pxStringToNumber(tokens.typography.textSans.small.fontSize),
    medium: convertValue.pxStringToNumber(tokens.typography.textSans.medium.fontSize),
    large: convertValue.pxStringToNumber(tokens.typography.textSans.large.fontSize),
    xlarge: convertValue.pxStringToNumber(tokens.typography.textSans.xLarge.fontSize),
    xxlarge: convertValue.pxStringToNumber(tokens.typography.textSans.xxLarge.fontSize),
    xxxlarge: convertValue.pxStringToNumber(tokens.typography.textSans.xxxLarge.fontSize)
  },
  body: {
    xsmall: convertValue.pxStringToNumber(tokens.typography.body.xSmall.fontSize),
    small: convertValue.pxStringToNumber(tokens.typography.body.small.fontSize),
    medium: convertValue.pxStringToNumber(tokens.typography.body.medium.fontSize)
  },
  headline: {
    xxxsmall: convertValue.pxStringToNumber(tokens.typography.headline.xxxSmall.fontSize),
    xxsmall: convertValue.pxStringToNumber(tokens.typography.headline.xxSmall.fontSize),
    xsmall: convertValue.pxStringToNumber(tokens.typography.headline.xSmall.fontSize),
    small: convertValue.pxStringToNumber(tokens.typography.headline.small.fontSize),
    medium: convertValue.pxStringToNumber(tokens.typography.headline.medium.fontSize),
    large: convertValue.pxStringToNumber(tokens.typography.headline.large.fontSize),
    xlarge: convertValue.pxStringToNumber(tokens.typography.headline.xLarge.fontSize)
  },
  titlepiece: {
    small: convertValue.pxStringToNumber(tokens.typography.titlepiece.small.fontSize),
    medium: convertValue.pxStringToNumber(tokens.typography.titlepiece.medium.fontSize),
    large: convertValue.pxStringToNumber(tokens.typography.titlepiece.large.fontSize)
  }
};
const remTextSizes = {
  textSans: {
    xxsmall: convertValue.pxToRem(pxTextSizes.textSans.xxsmall),
    xsmall: convertValue.pxToRem(pxTextSizes.textSans.xsmall),
    small: convertValue.pxToRem(pxTextSizes.textSans.small),
    medium: convertValue.pxToRem(pxTextSizes.textSans.medium),
    large: convertValue.pxToRem(pxTextSizes.textSans.large),
    xlarge: convertValue.pxToRem(pxTextSizes.textSans.xlarge),
    xxlarge: convertValue.pxToRem(pxTextSizes.textSans.xxlarge),
    xxxlarge: convertValue.pxToRem(pxTextSizes.textSans.xxxlarge)
  },
  body: {
    xsmall: convertValue.pxToRem(pxTextSizes.body.xsmall),
    small: convertValue.pxToRem(pxTextSizes.body.small),
    medium: convertValue.pxToRem(pxTextSizes.body.medium)
  },
  headline: {
    xxxsmall: convertValue.pxToRem(pxTextSizes.headline.xxxsmall),
    xxsmall: convertValue.pxToRem(pxTextSizes.headline.xxsmall),
    xsmall: convertValue.pxToRem(pxTextSizes.headline.xsmall),
    small: convertValue.pxToRem(pxTextSizes.headline.small),
    medium: convertValue.pxToRem(pxTextSizes.headline.medium),
    large: convertValue.pxToRem(pxTextSizes.headline.large),
    xlarge: convertValue.pxToRem(pxTextSizes.headline.xlarge)
  },
  titlepiece: {
    small: convertValue.pxToRem(pxTextSizes.titlepiece.small),
    medium: convertValue.pxToRem(pxTextSizes.titlepiece.medium),
    large: convertValue.pxToRem(pxTextSizes.titlepiece.large)
  }
};
const fonts = {
  titlepiece: convertValue.fontArrayToString(tokens.typography.fontFamily.titlepiece),
  headline: convertValue.fontArrayToString(tokens.typography.fontFamily.headline),
  body: convertValue.fontArrayToString(tokens.typography.fontFamily.body),
  textSans: convertValue.fontArrayToString(tokens.typography.fontFamily.textSans)
};
const lineHeights = {
  tight: tokens.typography.lineHeight.tight,
  regular: tokens.typography.lineHeight.regular,
  loose: tokens.typography.lineHeight.loose
};
const fontWeights = {
  light: tokens.typography.fontWeight.light,
  regular: tokens.typography.fontWeight.regular,
  medium: tokens.typography.fontWeight.medium,
  bold: tokens.typography.fontWeight.bold
};
const availableFontWeights = {
  titlepiece: { bold: true },
  headline: { light: true, medium: true, bold: true },
  body: { regular: true, bold: true },
  textSans: { regular: true, bold: true }
};
const italicsFontWeights = {
  titlepiece: { bold: false },
  headline: { light: true, medium: true, bold: false },
  body: { regular: true, bold: true },
  textSans: { regular: true, bold: false }
};
const underlineThickness = {
  textSans: {
    xxsmall: convertValue.pxStringToNumber(
      tokens.typography.textDecorationThicknessForFontSize[12]
    ),
    xsmall: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[14]),
    small: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[15]),
    medium: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[17]),
    large: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[20]),
    xlarge: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[24]),
    xxlarge: convertValue.pxStringToNumber(
      tokens.typography.textDecorationThicknessForFontSize[28]
    ),
    xxxlarge: convertValue.pxStringToNumber(
      tokens.typography.textDecorationThicknessForFontSize[34]
    )
  },
  body: {
    xsmall: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[14]),
    small: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[15]),
    medium: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[17])
  },
  headline: {
    xxxsmall: convertValue.pxStringToNumber(
      tokens.typography.textDecorationThicknessForFontSize[17]
    ),
    xxsmall: convertValue.pxStringToNumber(
      tokens.typography.textDecorationThicknessForFontSize[20]
    ),
    xsmall: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[24]),
    small: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[28]),
    medium: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[34]),
    large: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[42]),
    xlarge: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[50])
  },
  titlepiece: {
    small: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[42]),
    medium: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[50]),
    large: convertValue.pxStringToNumber(tokens.typography.textDecorationThicknessForFontSize[70])
  }
};
const textSansSizes = pxTextSizes.textSans;
const bodySizes = pxTextSizes.body;
const headlineSizes = pxTextSizes.headline;
const titlepieceSizes = pxTextSizes.titlepiece;
const remBodySizes = remTextSizes.body;
const remTitlepieceSizes = remTextSizes.titlepiece;
const remHeadlineSizes = remTextSizes.headline;
const remTextSansSizes = remTextSizes.textSans;

exports.availableFontWeights = availableFontWeights;
exports.bodySizes = bodySizes;
exports.fontWeights = fontWeights;
exports.fonts = fonts;
exports.headlineSizes = headlineSizes;
exports.italicsFontWeights = italicsFontWeights;
exports.lineHeights = lineHeights;
exports.pxTextSizes = pxTextSizes;
exports.remBodySizes = remBodySizes;
exports.remHeadlineSizes = remHeadlineSizes;
exports.remTextSansSizes = remTextSansSizes;
exports.remTextSizes = remTextSizes;
exports.remTitlepieceSizes = remTitlepieceSizes;
exports.textSansSizes = textSansSizes;
exports.titlepieceSizes = titlepieceSizes;
exports.underlineThickness = underlineThickness;
