import { typography } from '../../design-tokens/vendor/tokens.js';
import { pxStringToNumber, fontArrayToString, pxToRem } from '../../utils/convert-value.js';

const pxTextSizes = {
  textSans: {
    xxsmall: pxStringToNumber(typography.textSans.xxSmall.fontSize),
    xsmall: pxStringToNumber(typography.textSans.xSmall.fontSize),
    small: pxStringToNumber(typography.textSans.small.fontSize),
    medium: pxStringToNumber(typography.textSans.medium.fontSize),
    large: pxStringToNumber(typography.textSans.large.fontSize),
    xlarge: pxStringToNumber(typography.textSans.xLarge.fontSize),
    xxlarge: pxStringToNumber(typography.textSans.xxLarge.fontSize),
    xxxlarge: pxStringToNumber(typography.textSans.xxxLarge.fontSize)
  },
  body: {
    xsmall: pxStringToNumber(typography.body.xSmall.fontSize),
    small: pxStringToNumber(typography.body.small.fontSize),
    medium: pxStringToNumber(typography.body.medium.fontSize)
  },
  headline: {
    xxxsmall: pxStringToNumber(typography.headline.xxxSmall.fontSize),
    xxsmall: pxStringToNumber(typography.headline.xxSmall.fontSize),
    xsmall: pxStringToNumber(typography.headline.xSmall.fontSize),
    small: pxStringToNumber(typography.headline.small.fontSize),
    medium: pxStringToNumber(typography.headline.medium.fontSize),
    large: pxStringToNumber(typography.headline.large.fontSize),
    xlarge: pxStringToNumber(typography.headline.xLarge.fontSize)
  },
  titlepiece: {
    small: pxStringToNumber(typography.titlepiece.small.fontSize),
    medium: pxStringToNumber(typography.titlepiece.medium.fontSize),
    large: pxStringToNumber(typography.titlepiece.large.fontSize)
  }
};
const remTextSizes = {
  textSans: {
    xxsmall: pxToRem(pxTextSizes.textSans.xxsmall),
    xsmall: pxToRem(pxTextSizes.textSans.xsmall),
    small: pxToRem(pxTextSizes.textSans.small),
    medium: pxToRem(pxTextSizes.textSans.medium),
    large: pxToRem(pxTextSizes.textSans.large),
    xlarge: pxToRem(pxTextSizes.textSans.xlarge),
    xxlarge: pxToRem(pxTextSizes.textSans.xxlarge),
    xxxlarge: pxToRem(pxTextSizes.textSans.xxxlarge)
  },
  body: {
    xsmall: pxToRem(pxTextSizes.body.xsmall),
    small: pxToRem(pxTextSizes.body.small),
    medium: pxToRem(pxTextSizes.body.medium)
  },
  headline: {
    xxxsmall: pxToRem(pxTextSizes.headline.xxxsmall),
    xxsmall: pxToRem(pxTextSizes.headline.xxsmall),
    xsmall: pxToRem(pxTextSizes.headline.xsmall),
    small: pxToRem(pxTextSizes.headline.small),
    medium: pxToRem(pxTextSizes.headline.medium),
    large: pxToRem(pxTextSizes.headline.large),
    xlarge: pxToRem(pxTextSizes.headline.xlarge)
  },
  titlepiece: {
    small: pxToRem(pxTextSizes.titlepiece.small),
    medium: pxToRem(pxTextSizes.titlepiece.medium),
    large: pxToRem(pxTextSizes.titlepiece.large)
  }
};
const fonts = {
  titlepiece: fontArrayToString(typography.fontFamily.titlepiece),
  headline: fontArrayToString(typography.fontFamily.headline),
  body: fontArrayToString(typography.fontFamily.body),
  textSans: fontArrayToString(typography.fontFamily.textSans)
};
const lineHeights = {
  tight: typography.lineHeight.tight,
  regular: typography.lineHeight.regular,
  loose: typography.lineHeight.loose
};
const fontWeights = {
  light: typography.fontWeight.light,
  regular: typography.fontWeight.regular,
  medium: typography.fontWeight.medium,
  bold: typography.fontWeight.bold
};
const availableFontWeights = {
  titlepiece: { bold: true },
  headline: { light: true, medium: true, bold: true },
  body: { regular: true, bold: true },
  textSans: { regular: true, bold: true }
};
const italicsFontWeights = {
  titlepiece: { bold: false },
  headline: { light: true, medium: true, bold: false },
  body: { regular: true, bold: true },
  textSans: { regular: true, bold: false }
};
const underlineThickness = {
  textSans: {
    xxsmall: pxStringToNumber(
      typography.textDecorationThicknessForFontSize[12]
    ),
    xsmall: pxStringToNumber(typography.textDecorationThicknessForFontSize[14]),
    small: pxStringToNumber(typography.textDecorationThicknessForFontSize[15]),
    medium: pxStringToNumber(typography.textDecorationThicknessForFontSize[17]),
    large: pxStringToNumber(typography.textDecorationThicknessForFontSize[20]),
    xlarge: pxStringToNumber(typography.textDecorationThicknessForFontSize[24]),
    xxlarge: pxStringToNumber(
      typography.textDecorationThicknessForFontSize[28]
    ),
    xxxlarge: pxStringToNumber(
      typography.textDecorationThicknessForFontSize[34]
    )
  },
  body: {
    xsmall: pxStringToNumber(typography.textDecorationThicknessForFontSize[14]),
    small: pxStringToNumber(typography.textDecorationThicknessForFontSize[15]),
    medium: pxStringToNumber(typography.textDecorationThicknessForFontSize[17])
  },
  headline: {
    xxxsmall: pxStringToNumber(
      typography.textDecorationThicknessForFontSize[17]
    ),
    xxsmall: pxStringToNumber(
      typography.textDecorationThicknessForFontSize[20]
    ),
    xsmall: pxStringToNumber(typography.textDecorationThicknessForFontSize[24]),
    small: pxStringToNumber(typography.textDecorationThicknessForFontSize[28]),
    medium: pxStringToNumber(typography.textDecorationThicknessForFontSize[34]),
    large: pxStringToNumber(typography.textDecorationThicknessForFontSize[42]),
    xlarge: pxStringToNumber(typography.textDecorationThicknessForFontSize[50])
  },
  titlepiece: {
    small: pxStringToNumber(typography.textDecorationThicknessForFontSize[42]),
    medium: pxStringToNumber(typography.textDecorationThicknessForFontSize[50]),
    large: pxStringToNumber(typography.textDecorationThicknessForFontSize[70])
  }
};
const textSansSizes = pxTextSizes.textSans;
const bodySizes = pxTextSizes.body;
const headlineSizes = pxTextSizes.headline;
const titlepieceSizes = pxTextSizes.titlepiece;
const remBodySizes = remTextSizes.body;
const remTitlepieceSizes = remTextSizes.titlepiece;
const remHeadlineSizes = remTextSizes.headline;
const remTextSansSizes = remTextSizes.textSans;

export { availableFontWeights, bodySizes, fontWeights, fonts, headlineSizes, italicsFontWeights, lineHeights, pxTextSizes, remBodySizes, remHeadlineSizes, remTextSansSizes, remTextSizes, remTitlepieceSizes, textSansSizes, titlepieceSizes, underlineThickness };
