'use strict';

var data = require('./data.cjs');

const determineFontStyleProperty = (fontStyle, hasItalic) => {
  switch (fontStyle) {
    case "italic":
      return hasItalic ? "italic" : void 0;
    case "normal":
      return "normal";
    case null:
    default:
      return void 0;
  }
};
const fontStyleFunction = (category, level, defaults) => (options) => {
  const finalFontConfiguration = {
    ...defaults,
    ...options
  };
  const pxTextSize = Number(data.pxTextSizes[category][level]);
  const remTextSize = Number(data.remTextSizes[category][level]);
  const hasItalic = data.italicsFontWeights[category]?.[finalFontConfiguration.fontWeight] ?? false;
  const isFontWeightAvailable = data.availableFontWeights[category]?.[finalFontConfiguration.fontWeight] ?? false;
  const fontWeight = isFontWeightAvailable ? data.fontWeights[finalFontConfiguration.fontWeight] : void 0;
  const lineHeight = finalFontConfiguration.unit === "px" ? `${data.lineHeights[finalFontConfiguration.lineHeight] * pxTextSize}px` : data.lineHeights[finalFontConfiguration.lineHeight];
  return {
    lineHeight,
    fontWeight,
    fontSize: finalFontConfiguration.unit === "px" ? pxTextSize : `${remTextSize}rem`,
    fontFamily: data.fonts[category],
    textDecorationThickness: Number(data.underlineThickness[category][level]),
    fontStyle: determineFontStyleProperty(
      finalFontConfiguration.fontStyle,
      hasItalic
    )
  };
};
const fontStyleToStringFunction = (typographyFunction) => (options) => {
  const {
    fontFamily,
    fontSize,
    fontStyle,
    fontWeight,
    lineHeight,
    textDecorationThickness
  } = typographyFunction(options);
  return `
			font-family: ${fontFamily};
			font-size: ${typeof fontSize === "number" ? `${fontSize}px` : fontSize};
			line-height: ${lineHeight};
			${fontWeight ? `font-weight: ${fontWeight};` : ""}
			${fontStyle ? `font-style: ${fontStyle};` : ""}
			--source-text-decoration-thickness: ${textDecorationThickness === void 0 ? "auto" : `${textDecorationThickness}px`};
		`;
};

exports.fontStyleFunction = fontStyleFunction;
exports.fontStyleToStringFunction = fontStyleToStringFunction;
