'use strict';

var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
const TAB_KEY_CODE = 9;
class InteractionModeEngine {
  constructor(container, className) {
    this.container = container;
    this.className = className;
    __publicField(this, "isRunning", false);
    __publicField(this, "handleKeyDown", (e) => {
      if (e.which === TAB_KEY_CODE) {
        this.reset();
        this.container.addEventListener("mousedown", this.handleMouseDown);
      }
    });
    __publicField(this, "handleMouseDown", () => {
      this.reset();
      this.container.classList.add(this.className);
      this.container.addEventListener(
        "keydown",
        this.handleKeyDown
      );
    });
  }
  /** Returns whether the engine is currently running. */
  isActive() {
    return this.isRunning;
  }
  /** Enable behavior which applies the given className when in mouse mode. */
  start() {
    this.container.addEventListener("mousedown", this.handleMouseDown);
    this.isRunning = true;
  }
  /** Disable interaction mode behavior and remove className from container. */
  stop() {
    this.reset();
    this.isRunning = false;
  }
  reset() {
    this.container.classList.remove(this.className);
    this.container.removeEventListener(
      "keydown",
      this.handleKeyDown
    );
    this.container.removeEventListener("mousedown", this.handleMouseDown);
  }
}
const FOCUS_DISABLED = "src-focus-disabled";
let _focusEngine;
const focusEngine = () => {
  if (!_focusEngine) {
    _focusEngine = new InteractionModeEngine(
      document.documentElement,
      FOCUS_DISABLED
    );
  }
  return _focusEngine;
};
const FocusStyleManager = {
  alwaysShowFocus: () => focusEngine().stop(),
  isActive: () => focusEngine().isActive(),
  onlyShowFocusOnTabs: () => focusEngine().start()
};

exports.FocusStyleManager = FocusStyleManager;
exports.InteractionModeEngine = InteractionModeEngine;
