'use strict';

var tokens = require('../design-tokens/vendor/tokens.cjs');
var convertValue = require('../utils/convert-value.cjs');

const size = {
  xsmall: convertValue.pxStringToNumber(tokens.size.xSmall),
  small: convertValue.pxStringToNumber(tokens.size.small),
  medium: convertValue.pxStringToNumber(tokens.size.medium)
  // meets WCAG 2.1 AAA compliance for touch targets.
};
const remSize = {
  xsmall: convertValue.pxToRem(size.xsmall),
  small: convertValue.pxToRem(size.small),
  medium: convertValue.pxToRem(size.medium)
};
const iconSize = {
  xsmall: convertValue.pxStringToNumber(tokens.size.icon.xSmall),
  small: convertValue.pxStringToNumber(tokens.size.icon.small),
  medium: convertValue.pxStringToNumber(tokens.size.icon.medium)
};
const remIconSize = {
  xsmall: convertValue.pxToRem(iconSize.xsmall),
  small: convertValue.pxToRem(iconSize.small),
  medium: convertValue.pxToRem(iconSize.medium)
};
const height = {
  ctaMedium: size.medium,
  ctaSmall: size.small,
  ctaXsmall: size.xsmall,
  inputMedium: size.medium,
  inputXsmall: size.xsmall,
  iconMedium: iconSize.medium,
  iconSmall: iconSize.small,
  iconXsmall: iconSize.xsmall
};
const remHeight = {
  ctaMedium: remSize.medium,
  ctaSmall: remSize.small,
  ctaXsmall: remSize.xsmall,
  inputMedium: remSize.medium,
  inputXsmall: remSize.xsmall,
  iconMedium: remIconSize.medium,
  iconSmall: remIconSize.small,
  iconXsmall: remIconSize.xsmall
};
const width = {
  ctaMedium: size.medium,
  ctaSmall: size.small,
  ctaXsmall: size.xsmall,
  inputXsmall: size.xsmall,
  iconMedium: iconSize.medium,
  iconSmall: iconSize.small,
  iconXsmall: iconSize.xsmall
};
const remWidth = {
  ctaMedium: remSize.medium,
  ctaSmall: remSize.small,
  ctaXsmall: remSize.xsmall,
  inputXsmall: remSize.xsmall,
  iconMedium: remIconSize.medium,
  iconSmall: remIconSize.small,
  iconXsmall: remIconSize.xsmall
};

exports.height = height;
exports.iconSize = iconSize;
exports.remHeight = remHeight;
exports.remWidth = remWidth;
exports.size = size;
exports.width = width;
